==> libreoffice-7.2.3.2.tar.xz: libreoffice-7.2.3.2/sw/source/core/docnode/swthreadjoiner.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <swthreadjoiner.hxx>
#include <com/sun/star/util/JobManager.hpp>
#include <comphelper/processfactory.hxx>
#include <osl/mutex.hxx>
#include <rtl/instance.hxx>

// Testing

using namespace ::com::sun::star;

namespace
{
class theJoinerMutex : public rtl::Static<osl::Mutex, theJoinerMutex>
{
};

uno::Reference<util::XJobManager> pThreadJoiner;
}

uno::Reference<util::XJobManager>& SwThreadJoiner::GetThreadJoiner()
{
    osl::MutexGuard aGuard(theJoinerMutex::get());

    if (!pThreadJoiner.is())
    {
        pThreadJoiner = util::JobManager::create(comphelper::getProcessComponentContext());
    }

    return pThreadJoiner;
}

void SwThreadJoiner::ReleaseThreadJoiner() { pThreadJoiner.clear(); }

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.3.7.orig.tar.xz: libreoffice-7.3.7.2/sw/source/core/docnode/swthreadjoiner.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <swthreadjoiner.hxx>
#include <com/sun/star/util/JobManager.hpp>
#include <comphelper/processfactory.hxx>
#include <osl/mutex.hxx>

// Testing

using namespace ::com::sun::star;

namespace
{
uno::Reference<util::XJobManager> pThreadJoiner;
}

uno::Reference<util::XJobManager>& SwThreadJoiner::GetThreadJoiner()
{
    static osl::Mutex theJoinerMutex;
    osl::MutexGuard aGuard(theJoinerMutex);

    if (!pThreadJoiner.is())
    {
        pThreadJoiner = util::JobManager::create(comphelper::getProcessComponentContext());
    }

    return pThreadJoiner;
}

void SwThreadJoiner::ReleaseThreadJoiner() { pThreadJoiner.clear(); }

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
